/*
 * libslp-location
 *
 * Copyright (c) 2010-2013 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <glib.h>
#include <bundle_internal.h>
#include "location-log.h"
#include "location-setting.h"

gint location_setting_get_key_val(keynode_t *key)
{
	g_return_val_if_fail(key, -1);
	int val = -1;
	switch (vconf_keynode_get_type(key)) {
	case VCONF_TYPE_INT:
		val = vconf_keynode_get_int(key);
		LOCATION_SECLOG("changed [%s]:[%d]", vconf_keynode_get_name(key), val);
		break;
	default:
		LOCATION_LOGW("Unused type(%d)", vconf_keynode_get_type(key));
		break;
	}
	return val;
}

gint location_setting_get_int(const gchar *path)
{
	g_return_val_if_fail(path, 0);
	int val = 0;
	if (vconf_get_int(path, &val))
		LOCATION_SECLOG("failed [%s]", path);

	return val;
}

gboolean location_setting_get_bool(const gchar *path)
{
	g_return_val_if_fail(path, FALSE);
	gboolean val = FALSE;
	if (vconf_get_bool(path, &val))
		LOCATION_SECLOG("failed [%s]", path);

	return val;
}

gint location_setting_add_notify(const gchar *path, SettingCB setting_cb, gpointer self)
{
	g_return_val_if_fail(path, -1);
	g_return_val_if_fail(self, -1);

	if (vconf_notify_key_changed(path, setting_cb, self)) {
		LOCATION_SECLOG("vconf notify add failed [%s]", path);
		return -1;
	}
	LOCATION_SECLOG("vconf notify added [%s]", path);
	return 0;
}

gint location_setting_ignore_notify(const gchar *path, SettingCB setting_cb)
{
	g_return_val_if_fail(path, -1);
	g_return_val_if_fail(setting_cb, -1);

	if (vconf_ignore_key_changed(path, setting_cb)) {
		LOCATION_SECLOG("vconf notify remove failed [%s]", path);
		return -1;
	}
	LOCATION_SECLOG("vconf notify removed [%s]", path);
	return 0;
}

gint location_state_add_notify(const gchar *path, SettingCB setting_cb, gpointer self)
{
	g_return_val_if_fail(path, -1);
	g_return_val_if_fail(self, -1);

	if (vconf_notify_key_changed(path, setting_cb, self)) {
		LOCATION_SECLOG("vconf notify add failed [%s]", path);
		return -1;
	}
	LOCATION_SECLOG("vconf notify added [%s]", path);
	return 0;
}

gint location_state_ignore_notify(const gchar *path, SettingCB setting_cb)
{
	g_return_val_if_fail(path, -1);
	g_return_val_if_fail(setting_cb, -1);

	if (vconf_ignore_key_changed(path, setting_cb)) {
		LOCATION_SECLOG("vconf notify remove failed [%s]", path);
		return -1;
	}
	LOCATION_SECLOG("vconf notify removed [%s]", path);
	return 0;
}
